/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, useContext, useEffect} from 'react';
import styled from 'styled-components'
import CustomizedBreadcrumbs from '../Components/TabPanels/Breadcrumbs.js'
import { Store } from '../Store.js';
import Tabs from '@material-ui/core/Tabs';
import Tab from '@material-ui/core/Tab';
import Paper from '@material-ui/core/Paper';
import ModalAlterarAvatar from '../Components/ModalAlterarAvatar/ModalAlterarAvatar'
import TabPanelAtividades from '../Components/TabPanels/UserPageTabs/PanelAtividades.js'
import TabPanelMeusRecursos from '../Components/TabPanels/UserPageTabs/PanelMeusRecursos.js'
import TabPanelFavoritos from '../Components/TabPanels/UserPageTabs/PanelFavoritos.js'
import TabPanelColecoes from '../Components/TabPanels/UserPageTabs/PanelColecoes.js'
import TabPanelRede from '../Components/TabPanels/UserPageTabs/PanelRede.js'
import TabPanelStatusEConquistas from '../Components/TabPanels/TabPanelStatusEConquistas.js'
import TabPanelCuradoria from '../Components/TabPanels/UserPageTabs/PanelCuradoria.js'
import axios from 'axios'
import {apiUrl, apiDomain} from '../env';
import Grid from '@material-ui/core/Grid';
import {HeaderContainer, UserProfileContainer, CheckTeacherDiv, StyledTabs, RodapeDiv, NavBarContentContainer, BackgroundDiv} from '../Components/TabPanels/StyledComponents.js'
    import Cover from '../Components/UserPageComponents/Cover.js'
import ProfileAvatar from '../Components/UserPageComponents/Avatar.js'
import UserInfo from '../Components/UserPageComponents/UserInfo.js'
import EditProfileButton from '../Components/UserPageComponents/EditProfileButton.js'
import SubmitterStatus from '../Components/UserPageComponents/SubmitterStatus.js'

const GetHeaderConfig = () => {

    let config = {
        headers : {
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Access-Token': sessionStorage.getItem('@portalmec/accessToken'),
            'Client': sessionStorage.getItem('@portalmec/clientToken'),
            'Uid': sessionStorage.getItem('@portalmec/uid'),
        }
    }
    {/*'Host': 'api.portalmec.c3sl.ufpr.br',
    'Cookie': ''*/}
    return config
}

export default function UserPage (props){
    const {state} = useContext(Store)
    const id = state.currentUser.id

    const [tabValue, setTabValue] = useState(
        Number(props.location.state) || 0
    );
    const [tabs, setTabs] = useState([
        'Atividades', 'Meus Recursos', 'Favoritos', 'Coleções', 'Rede'
    ])
    const handleChangeTab = (event, newValue) => {
        setTabValue(newValue)
    }

    useEffect( () => {
        if (id != '') {
        axios.get( (`${apiUrl}/users/` + id), {
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Host': 'api.portalmec.c3sl.ufpr.br',
            'Cookie': ''
        })
        .then( (response) => {
            console.log(response)

                if((response.data.role_ids.includes(4))) {
                    setTabs([
                        'Atividades', 'Meus Recursos', 'Favoritos', 'Coleções', 'Rede', 'Curadoria'
                    ])
                }
            },
            (error) => {
                console.log('error while running ComponentDidMout')
            }
        )}
    }, [])

    const redirect = () => {
        props.history.push('/')
    }

    const [modalOpen, toggleModal] = useState(false)

    return (
        <>
        <link href="https://fonts.googleapis.com/css?family=Roboto:100,400,500&display=swap" rel="stylesheet"/>
        {
            state.userIsLoggedIn?
            (
                [
                    <React.Fragment>
                        <ModalAlterarAvatar
                            open={modalOpen}
                            handleClose={() => {toggleModal(false)}}
                            userAvatar={state.currentUser.avatar_file_name}
                        />

                    <BackgroundDiv>

                            <CustomizedBreadcrumbs
                                values={["Minha área", tabs[tabValue]]}
                            />
                            <Grid container spacing={2}>
                                <Grid item xs={12}>
                                    <div style={{padding : "10px 0 8px 0"}}>
                                        <UserProfileContainer>
                                            <HeaderContainer>
                                                <Cover id={id}/>
                                                <ProfileAvatar id={id}/>
                                                <UserInfo/>
                                                <EditProfileButton/>
                                            </HeaderContainer>

                                            <CheckTeacherDiv>
                                                <SubmitterStatus />
                                            </CheckTeacherDiv>

                                            <RodapeDiv>
                                                <NavBarContentContainer>
                                                    <StyledTabs
                                                        value ={tabValue}
                                                        onChange ={handleChangeTab}
                                                        indicatorColor ="primary"
                                                        textColor ="primary"
                                                        variant = "scrollable"
                                                        scrollButtons = "auto"
                                                        TabIndicatorProps={{style : {background:"#00bcd4"}}}
                                                    >
                                                        {
                                                            tabs.map( (tab) =>
                                                                <StyledTab label ={tab} key={tab}/>
                                                            )
                                                        }

                                                    </StyledTabs>
                                                </NavBarContentContainer>
                                            </RodapeDiv>
                                        </UserProfileContainer>
                                    </div>
                                </Grid>

                                <Grid item xs={12}>
                                    {tabValue === 0 &&
                                        <TabPanelAtividades id={id} config={GetHeaderConfig()}/>}
                                    {tabValue === 1 &&
                                        <TabPanelMeusRecursos id={id} config={GetHeaderConfig()}/>}
                                    {tabValue === 2 &&
                                        <TabPanelFavoritos id={id} config={GetHeaderConfig()}/>}
                                    {tabValue === 3 &&
                                        <TabPanelColecoes id={id} config={GetHeaderConfig()}/>}
                                    {tabValue === 4 &&
                                        <TabPanelRede id={id} config={GetHeaderConfig()}/>}
                                    {tabValue === 5 &&
                                        <TabPanelCuradoria id={id} config={GetHeaderConfig()}/>}
                                </Grid>
                            </Grid>
                        </BackgroundDiv>
                    </React.Fragment>
                ]
            )
            : (
                <>
                {redirect()}
                </>
            )
        }
        </>

      )

  }


const StyledTab = styled(Tab)`
    .Mui-selected {
        border-bottom-color : #00bcd4 !important;
    }
    .MuiTab-wrapper {
        border-bottom-color : #00bcd4 !important;
    }
`
